You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@directory.apache.org by el...@apache.org on 2005/06/08 23:29:21 UTC

svn commit: r189643 - in /directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1: ./ ber/grammar/ ldap/codec/ ldap/codec/grammars/ ldap/pojo/ ldap/pojo/filters/ spnego/codec/ spnego/codec/grammars/ spnego/pojo/

Author: elecharny
Date: Wed Jun  8 14:29:20 2005
New Revision: 189643

URL: http://svn.apache.org/viewcvs?rev=189643&view=rev
Log:
Deleted the Asn1POJO interface

Removed:
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/AbstractPOJO.java
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/Asn1POJO.java
Modified:
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ber/grammar/AbstractGrammar.java
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/LdapMessageContainer.java
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/AbandonRequestGrammar.java
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/AddResponseGrammar.java
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/BindRequestGrammar.java
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/BindResponseGrammar.java
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/CompareResponseGrammar.java
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/DelResponseGrammar.java
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/FilterGrammar.java
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/LdapMessageGrammar.java
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/LdapResultGrammar.java
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/ModifyDNResponseGrammar.java
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/ModifyResponseGrammar.java
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/SearchRequestGrammar.java
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/SearchResultDoneGrammar.java
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/UnBindRequestGrammar.java
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/BindRequest.java
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/Controls.java
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/LdapMessage.java
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/LdapResult.java
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/Response.java
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/SaslAuthentication.java
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/SearchRequest.java
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/SimpleAuthentication.java
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/SubstringFilter.java
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/UnBindRequest.java
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/filters/AndFilter.java
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/filters/AttributeValueAssertionFilter.java
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/filters/Filter.java
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/filters/NotFilter.java
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/filters/OrFilter.java
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/spnego/codec/SpnegoContainer.java
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/spnego/codec/grammars/SpnegoGrammar.java
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/spnego/pojo/Spnego.java
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/spnego/pojo/SpnegoNegTokenInit.java
    directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/spnego/pojo/SpnegoNegTokenTarg.java

Modified: directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ber/grammar/AbstractGrammar.java
URL: http://svn.apache.org/viewcvs/directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ber/grammar/AbstractGrammar.java?rev=189643&r1=189642&r2=189643&view=diff
==============================================================================
--- directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/LdapMessageContainer.java (original)
+++ directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/LdapMessageContainer.java Wed Jun  8 14:29:20 2005
@@ -97,7 +97,7 @@
     }
 
     /**
-     * Set a ldapMessage POJO into the container. It will be completed
+     * Set a ldapMessage Object into the container. It will be completed
      * by the ldapDecoder .
      *
      * @param ldapMessage The ldapMessage to set.

Modified: directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/AbandonRequestGrammar.java
URL: http://svn.apache.org/viewcvs/directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/AbandonRequestGrammar.java?rev=189643&r1=189642&r2=189643&view=diff
==============================================================================
--- directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/AbandonRequestGrammar.java (original)
+++ directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/AbandonRequestGrammar.java Wed Jun  8 14:29:20 2005
@@ -99,7 +99,7 @@
                 } );
 
         //  AbandonRequest ::= [APPLICATION 16] MessageID (Value)
-        // Checks that MessageId is in [0 .. 2147483647] and store the value in the AbandonRequest POJO
+        // Checks that MessageId is in [0 .. 2147483647] and store the value in the AbandonRequest Object
         // (2147483647 = Integer.MAX_VALUE)
         // This is the last state.
         super.transitions[LdapStatesEnum.ABANDON_REQUEST_MESSAGE_ID_VALUE][0x50] =
@@ -131,8 +131,8 @@
                         {
 
                             // Ok, the Message ID is correct. We have to allocate an
-                            // abandonRequest POJO to store the value, and store the
-                            // POJO in the LDAPMessage
+                            // abandonRequest Object to store the value, and store the
+                            // Object in the LDAPMessage
                             AbandonRequest abandonRequest = new AbandonRequest();
                             abandonRequest.setMessageId( messageId );
                             ldapMessage.setProtocolOP( abandonRequest );

Modified: directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/AddResponseGrammar.java
URL: http://svn.apache.org/viewcvs/directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/AddResponseGrammar.java?rev=189643&r1=189642&r2=189643&view=diff
==============================================================================
--- directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/AddResponseGrammar.java (original)
+++ directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/AddResponseGrammar.java Wed Jun  8 14:29:20 2005
@@ -89,7 +89,7 @@
                         checkLength( ldapMessageContainer.getLdapMessage(),
                             ldapMessageContainer.getCurrentTLV() );
 
-                        // Now, we can allocate the AdddRequest POJO
+                        // Now, we can allocate the AdddRequest Object
                         AddResponse addResponse = new AddResponse();
 
                         // As this is a new Constructed object, we have to init its length
@@ -97,9 +97,9 @@
                         int expectedLength = tlv.getLength().getLength();
                         addResponse.setExpectedLength( expectedLength );
                         addResponse.setCurrentLength( 0 );
-                        addResponse.setFather( ldapMessage );
+                        addResponse.setParent( ldapMessage );
 
-                        // And we associate it to the ldapMessage POJO
+                        // And we associate it to the ldapMessage Object
                         ldapMessage.setProtocolOP( addResponse );
                     }
                 } );

Modified: directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/BindRequestGrammar.java
URL: http://svn.apache.org/viewcvs/directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/BindRequestGrammar.java?rev=189643&r1=189642&r2=189643&view=diff
==============================================================================
--- directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/BindResponseGrammar.java (original)
+++ directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/BindResponseGrammar.java Wed Jun  8 14:29:20 2005
@@ -92,7 +92,7 @@
                         checkLength( ldapMessageContainer.getLdapMessage(),
                             ldapMessageContainer.getCurrentTLV() );
 
-                        // Now, we can allocate the BindRequest POJO
+                        // Now, we can allocate the BindRequest Object
                         BindResponse bindResponse = new BindResponse();
 
                         // As this is a new Constructed object, we have to init its length
@@ -100,9 +100,9 @@
                         int expectedLength = tlv.getLength().getLength();
                         bindResponse.setExpectedLength( expectedLength );
                         bindResponse.setCurrentLength( 0 );
-                        bindResponse.setFather( ldapMessage );
+                        bindResponse.setParent( ldapMessage );
 
-                        // And we associate it to the ldapMessage POJO
+                        // And we associate it to the ldapMessage Object
                         ldapMessage.setProtocolOP( bindResponse );
                     }
                 } );
@@ -178,7 +178,7 @@
         //     ...
         //    serverSaslCreds   [7] OCTET STRING OPTIONAL } (Length)
         //
-        // We have to get the server sasl Credentials and store it in the BindResponse POJO.
+        // We have to get the server sasl Credentials and store it in the BindResponse Object.
         // Two different following states are possible :
         // - a Controls tag (0x80)
         // - nothing at all (end of the BindResponse).

Modified: directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/CompareResponseGrammar.java
URL: http://svn.apache.org/viewcvs/directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/CompareResponseGrammar.java?rev=189643&r1=189642&r2=189643&view=diff
==============================================================================
--- directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/CompareResponseGrammar.java (original)
+++ directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/CompareResponseGrammar.java Wed Jun  8 14:29:20 2005
@@ -89,7 +89,7 @@
                         checkLength( ldapMessageContainer.getLdapMessage(),
                             ldapMessageContainer.getCurrentTLV() );
 
-                        // Now, we can allocate the AdddRequest POJO
+                        // Now, we can allocate the AdddRequest Object
                         CompareResponse compareResponse = new CompareResponse();
 
                         // As this is a new Constructed object, we have to init its length
@@ -97,9 +97,9 @@
                         int expectedLength = tlv.getLength().getLength();
                         compareResponse.setExpectedLength( expectedLength );
                         compareResponse.setCurrentLength( 0 );
-                        compareResponse.setFather( ldapMessage );
+                        compareResponse.setParent( ldapMessage );
 
-                        // And we associate it to the ldapMessage POJO
+                        // And we associate it to the ldapMessage Object
                         ldapMessage.setProtocolOP( compareResponse );
                     }
                 } );

Modified: directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/DelResponseGrammar.java
URL: http://svn.apache.org/viewcvs/directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/DelResponseGrammar.java?rev=189643&r1=189642&r2=189643&view=diff
==============================================================================
--- directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/DelResponseGrammar.java (original)
+++ directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/DelResponseGrammar.java Wed Jun  8 14:29:20 2005
@@ -89,7 +89,7 @@
                         checkLength( ldapMessageContainer.getLdapMessage(),
                             ldapMessageContainer.getCurrentTLV() );
 
-                        // Now, we can allocate the DelResponse POJO
+                        // Now, we can allocate the DelResponse Object
                         DelResponse delResponse = new DelResponse();
 
                         // As this is a new Constructed object, we have to init its length
@@ -97,9 +97,9 @@
                         int expectedLength = tlv.getLength().getLength();
                         delResponse.setExpectedLength( expectedLength );
                         delResponse.setCurrentLength( 0 );
-                        delResponse.setFather( ldapMessage );
+                        delResponse.setParent( ldapMessage );
 
-                        // And we associate it to the ldapMessage POJO
+                        // And we associate it to the ldapMessage Object
                         ldapMessage.setProtocolOP( delResponse );
                     }
                 } );

Modified: directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/FilterGrammar.java
URL: http://svn.apache.org/viewcvs/directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/FilterGrammar.java?rev=189643&r1=189642&r2=189643&view=diff
==============================================================================
--- directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/LdapMessageGrammar.java (original)
+++ directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/LdapMessageGrammar.java Wed Jun  8 14:29:20 2005
@@ -81,7 +81,7 @@
                         LdapMessageContainer ldapMessageContainer = ( LdapMessageContainer )
                             container;
 
-                        // First, create a empty LdapMessage POJO
+                        // First, create a empty LdapMessage Object
                         LdapMessage ldapMessage = new LdapMessage();
 
                         // Then stores it into the container
@@ -146,7 +146,7 @@
                 } );
 
         // LDAPMessage --> ... MessageId ...(Value)
-        // Checks that MessageId is in [0 .. 2147483647] and store the value in the LdapMessage POJO
+        // Checks that MessageId is in [0 .. 2147483647] and store the value in the LdapMessage Object
         // (2147483647 = Integer.MAX_VALUE)
         super.transitions[LdapStatesEnum.LDAP_MESSAGE_ID_VALUE][0x02] = new GrammarTransition(
                 LdapStatesEnum.LDAP_MESSAGE_ID_VALUE, LdapStatesEnum.PROTOCOL_OP_TAG,

Modified: directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/LdapResultGrammar.java
URL: http://svn.apache.org/viewcvs/directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/LdapResultGrammar.java?rev=189643&r1=189642&r2=189643&view=diff
==============================================================================
--- directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/LdapResultGrammar.java (original)
+++ directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/LdapResultGrammar.java Wed Jun  8 14:29:20 2005
@@ -108,7 +108,7 @@
 
                         ldapResult.setExpectedLength( tlv.getLength().getLength() );
                         ldapResult.setCurrentLength( 0 );
-                        ldapResult.setFather( response );
+                        ldapResult.setParent( response );
 
                         checkLength( response, tlv );
 
@@ -441,8 +441,8 @@
 
                         checkLength( response, tlv );
 
-                        // We will use the LdapString POJO to check the expected length of the following
-                        // referrals. This is quite a trick, but as this POJO's expected length is never
+                        // We will use the LdapString Object to check the expected length of the following
+                        // referrals. This is quite a trick, but as this Object expected length is never
                         // used, it's just ok.
                         ldapResult.setExpectedLength( ldapMessageContainer.getCurrentTLV()
                             .getLength().getLength() );

Modified: directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/ModifyDNResponseGrammar.java
URL: http://svn.apache.org/viewcvs/directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/ModifyDNResponseGrammar.java?rev=189643&r1=189642&r2=189643&view=diff
==============================================================================
--- directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/ModifyDNResponseGrammar.java (original)
+++ directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/ModifyDNResponseGrammar.java Wed Jun  8 14:29:20 2005
@@ -89,7 +89,7 @@
                         checkLength( ldapMessageContainer.getLdapMessage(),
                             ldapMessageContainer.getCurrentTLV() );
 
-                        // Now, we can allocate the ModifyDNResponse POJO
+                        // Now, we can allocate the ModifyDNResponse Object
                         ModifyDNResponse modifyDNResponse = new ModifyDNResponse();
 
                         // As this is a new Constructed object, we have to init its length
@@ -97,9 +97,9 @@
                         int expectedLength = tlv.getLength().getLength();
                         modifyDNResponse.setExpectedLength( expectedLength );
                         modifyDNResponse.setCurrentLength( 0 );
-                        modifyDNResponse.setFather( ldapMessage );
+                        modifyDNResponse.setParent( ldapMessage );
 
-                        // And we associate it to the ldapMessage POJO
+                        // And we associate it to the ldapMessage Object
                         ldapMessage.setProtocolOP( modifyDNResponse );
                     }
                 } );

Modified: directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/ModifyResponseGrammar.java
URL: http://svn.apache.org/viewcvs/directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/ModifyResponseGrammar.java?rev=189643&r1=189642&r2=189643&view=diff
==============================================================================
--- directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/ModifyResponseGrammar.java (original)
+++ directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/ModifyResponseGrammar.java Wed Jun  8 14:29:20 2005
@@ -89,7 +89,7 @@
                         checkLength( ldapMessageContainer.getLdapMessage(),
                             ldapMessageContainer.getCurrentTLV() );
 
-                        // Now, we can allocate the ModifyResponse POJO
+                        // Now, we can allocate the ModifyResponse Object
                         ModifyResponse modifyResponse = new ModifyResponse();
 
                         // As this is a new Constructed object, we have to init its length
@@ -97,9 +97,9 @@
                         int expectedLength = tlv.getLength().getLength();
                         modifyResponse.setExpectedLength( expectedLength );
                         modifyResponse.setCurrentLength( 0 );
-                        modifyResponse.setFather( ldapMessage );
+                        modifyResponse.setParent( ldapMessage );
 
-                        // And we associate it to the ldapMessage POJO
+                        // And we associate it to the ldapMessage Object
                         ldapMessage.setProtocolOP( modifyResponse );
                     }
                 } );

Modified: directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/SearchRequestGrammar.java
URL: http://svn.apache.org/viewcvs/directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/SearchRequestGrammar.java?rev=189643&r1=189642&r2=189643&view=diff
==============================================================================
--- directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/SearchRequestGrammar.java (original)
+++ directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/SearchRequestGrammar.java Wed Jun  8 14:29:20 2005
@@ -106,9 +106,9 @@
 
                         searchRequest.setExpectedLength( expectedLength );
                         searchRequest.setCurrentLength( 0 );
-                        searchRequest.setFather( ldapMessage );
+                        searchRequest.setParent( ldapMessage );
 
-                        // And we associate it to the ldapMessage POJO
+                        // And we associate it to the ldapMessage Object
                         ldapMessage.setProtocolOP( searchRequest );
                     }
                 } );
@@ -532,7 +532,7 @@
         //    ...
         // We have a value for the typesOnly, we will store it in the message.
         // The next transition will deal with the Filter. As a filter could contains
-        // sub-filter, we will initialize the filter POJO right here. 
+        // sub-filter, we will initialize the filter Object right here. 
         super.transitions[LdapStatesEnum.SEARCH_REQUEST_TYPES_ONLY_VALUE][0x01] =
             new GrammarTransition( LdapStatesEnum.SEARCH_REQUEST_TYPES_ONLY_VALUE,
                 LdapStatesEnum.SEARCH_REQUEST_FILTER,

Modified: directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/SearchResultDoneGrammar.java
URL: http://svn.apache.org/viewcvs/directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/SearchResultDoneGrammar.java?rev=189643&r1=189642&r2=189643&view=diff
==============================================================================
--- directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/SearchResultDoneGrammar.java (original)
+++ directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/SearchResultDoneGrammar.java Wed Jun  8 14:29:20 2005
@@ -89,7 +89,7 @@
                         checkLength( ldapMessageContainer.getLdapMessage(),
                             ldapMessageContainer.getCurrentTLV() );
 
-                        // Now, we can allocate the SearchResultDone POJO
+                        // Now, we can allocate the SearchResultDone Object
                         SearchResultDone searchResultDone = new SearchResultDone();
 
                         // As this is a new Constructed object, we have to init its length
@@ -97,9 +97,9 @@
                         int expectedLength = tlv.getLength().getLength();
                         searchResultDone.setExpectedLength( expectedLength );
                         searchResultDone.setCurrentLength( 0 );
-                        searchResultDone.setFather( ldapMessage );
+                        searchResultDone.setParent( ldapMessage );
 
-                        // And we associate it to the ldapMessage POJO
+                        // And we associate it to the ldapMessage Object
                         ldapMessage.setProtocolOP( searchResultDone );
                     }
                 } );

Modified: directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/UnBindRequestGrammar.java
URL: http://svn.apache.org/viewcvs/directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/UnBindRequestGrammar.java?rev=189643&r1=189642&r2=189643&view=diff
==============================================================================
--- directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/UnBindRequestGrammar.java (original)
+++ directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/UnBindRequestGrammar.java Wed Jun  8 14:29:20 2005
@@ -104,7 +104,7 @@
 
                         checkLength( ldapMessage, ldapMessageContainer.getCurrentTLV() );
 
-                        // Now, we can allocate the UnBindRequest POJO
+                        // Now, we can allocate the UnBindRequest Object
                         UnBindRequest unBindRequest = new UnBindRequest();
 
                         // As this is a new Constructed object, we have to init its length
@@ -119,9 +119,9 @@
 
                         unBindRequest.setExpectedLength( expectedLength );
                         unBindRequest.setCurrentLength( 0 );
-                        unBindRequest.setFather( ldapMessage );
+                        unBindRequest.setParent( ldapMessage );
 
-                        // And we associate it to the ldapMessage POJO
+                        // And we associate it to the ldapMessage Object
                         ldapMessage.setProtocolOP( unBindRequest );
                     }
                 } );

Modified: directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/BindRequest.java
URL: http://svn.apache.org/viewcvs/directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/BindRequest.java?rev=189643&r1=189642&r2=189643&view=diff
==============================================================================
--- directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/Controls.java (original)
+++ directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/Controls.java Wed Jun  8 14:29:20 2005
@@ -16,14 +16,14 @@
  */
 package org.apache.asn1.ldap.pojo;
 
-import org.apache.asn1.AbstractPOJO;
+import org.apache.asn1.Asn1Object;
 
 /**
- * A POJO to store Controls.
+ * A ldapObject to store Controls.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  */
-public class Controls extends AbstractPOJO
+public class Controls extends Asn1Object
 {
     //~ Instance fields ----------------------------------------------------------------------------
 

Modified: directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/LdapMessage.java
URL: http://svn.apache.org/viewcvs/directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/LdapMessage.java?rev=189643&r1=189642&r2=189643&view=diff
==============================================================================
--- directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/Response.java (original)
+++ directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/Response.java Wed Jun  8 14:29:20 2005
@@ -17,7 +17,7 @@
 package org.apache.asn1.ldap.pojo;
 
 /**
- * A generic Response POJO. It will contain the LdapResult.
+ * A generic Response Object. It will contain the LdapResult.
  * 
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  */

Modified: directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/SaslAuthentication.java
URL: http://svn.apache.org/viewcvs/directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/SaslAuthentication.java?rev=189643&r1=189642&r2=189643&view=diff
==============================================================================
--- directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/SubstringFilter.java (original)
+++ directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/SubstringFilter.java Wed Jun  8 14:29:20 2005
@@ -20,7 +20,7 @@
 
 
 /**
- * A POJO that stores the substring filter. A substring filter follow this grammar :
+ * A Object that stores the substring filter. A substring filter follow this grammar :
  * substring  = attr "=" [initial] any [final]
  * initial    = value
  * any        = "*" *(value "*")

Modified: directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/UnBindRequest.java
URL: http://svn.apache.org/viewcvs/directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/UnBindRequest.java?rev=189643&r1=189642&r2=189643&view=diff
==============================================================================
--- directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/filters/AndFilter.java (original)
+++ directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/filters/AndFilter.java Wed Jun  8 14:29:20 2005
@@ -19,7 +19,7 @@
 import java.util.ArrayList;
 
 /**
- * And Filter POJO to store the And filter.
+ * And Filter Object to store the And filter.
  * 
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  */

Modified: directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/filters/AttributeValueAssertionFilter.java
URL: http://svn.apache.org/viewcvs/directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/filters/AttributeValueAssertionFilter.java?rev=189643&r1=189642&r2=189643&view=diff
==============================================================================
--- directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/filters/AttributeValueAssertionFilter.java (original)
+++ directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/filters/AttributeValueAssertionFilter.java Wed Jun  8 14:29:20 2005
@@ -20,7 +20,7 @@
 
 
 /**
- * POJO to store the filter. A filter is seen as a tree with a root.
+ * Object to store the filter. A filter is seen as a tree with a root.
  * 
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  */

Modified: directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/filters/Filter.java
URL: http://svn.apache.org/viewcvs/directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/filters/Filter.java?rev=189643&r1=189642&r2=189643&view=diff
==============================================================================
--- directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/filters/NotFilter.java (original)
+++ directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/filters/NotFilter.java Wed Jun  8 14:29:20 2005
@@ -17,7 +17,7 @@
 package org.apache.asn1.ldap.pojo.filters;
 
 /**
- * Not Filter POJO to store the Not filter.
+ * Not Filter Object to store the Not filter.
  * 
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  */

Modified: directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/filters/OrFilter.java
URL: http://svn.apache.org/viewcvs/directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/filters/OrFilter.java?rev=189643&r1=189642&r2=189643&view=diff
==============================================================================
--- directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/filters/OrFilter.java (original)
+++ directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/filters/OrFilter.java Wed Jun  8 14:29:20 2005
@@ -20,7 +20,7 @@
 
 
 /**
- * Or Filter POJO to store the Or filter.
+ * Or Filter Object to store the Or filter.
  * 
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  */

Modified: directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/spnego/codec/SpnegoContainer.java
URL: http://svn.apache.org/viewcvs/directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/spnego/codec/SpnegoContainer.java?rev=189643&r1=189642&r2=189643&view=diff
==============================================================================
--- directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/spnego/codec/SpnegoContainer.java (original)
+++ directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/spnego/codec/SpnegoContainer.java Wed Jun  8 14:29:20 2005
@@ -35,7 +35,7 @@
 {
     //~ Instance fields ----------------------------------------------------------------------------
 
-    /** The SPNEGO POJO */
+    /** The SPNEGO Object */
     private Spnego spnego;
     
     //~ Constructors -------------------------------------------------------------------------------
@@ -68,7 +68,7 @@
     }
 
     /**
-     * Set a spnego POJO into the container. It will be completed
+     * Set a spnegoObject into the container. It will be completed
      * by the spnego Decoder .
      *
      * @param spnego The spnego to set.

Modified: directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/spnego/codec/grammars/SpnegoGrammar.java
URL: http://svn.apache.org/viewcvs/directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/spnego/codec/grammars/SpnegoGrammar.java?rev=189643&r1=189642&r2=189643&view=diff
==============================================================================
--- directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/spnego/codec/grammars/SpnegoGrammar.java (original)
+++ directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/spnego/codec/grammars/SpnegoGrammar.java Wed Jun  8 14:29:20 2005
@@ -78,7 +78,7 @@
         //--------------------------------------------------------------------------------------------
         // SPNEGO --> CHOICE {
         //      negTokenInit  [0]  NegTokenInit, (Tag)
-        // We have a negTokenInit, and the tag must be 0xA0. We will create the Spnego POJO
+        // We have a negTokenInit, and the tag must be 0xA0. We will create the SpnegoObject
         // here, and store it in the container.
         super.transitions[SpnegoStatesEnum.SPNEGO_START_STATE][0xA0] =
             new GrammarTransition( SpnegoStatesEnum.SPNEGO_START_STATE,
@@ -89,11 +89,11 @@
                     {
                         SpnegoContainer spnegoContainer = ( SpnegoContainer ) container;
 
-                        // First, create a empty Spnego POJO
-                        Spnego spnegoPOJO = new SpnegoNegTokenInit();
+                        // First, create a empty SpnegoObject
+                        Spnego spnego = new SpnegoNegTokenInit();
 
                         // Then stores it into the container
-                        spnegoContainer.setSpnego( spnegoPOJO );
+                        spnegoContainer.setSpnego( spnego );
 
                         return;
                     }
@@ -101,7 +101,7 @@
 
         // SPNEGO --> CHOICE { ...
         //      negTokenInit  [0]  NegTokenInit, (Length)
-        // We get the negTokenInit length, and store it in the Spnego POJO
+        // We get the negTokenInit length, and store it in the SpnegoObject
         super.transitions[SpnegoStatesEnum.SPNEGO_NEG_TOKEN_INIT_LENGTH][0xA0] =
             new GrammarTransition( SpnegoStatesEnum.SPNEGO_NEG_TOKEN_INIT_LENGTH,
                 SpnegoStatesEnum.SPNEGO_NEG_TOKEN_INIT_VALUE,
@@ -819,7 +819,7 @@
         //--------------------------------------------------------------------------------------------
         // SPNEGO --> CHOICE {
         //      negTokenTarg  [1]  NegTokenTarg, (Tag)
-        // We have a negTokenTarg, and the tag must be 0xA1. We will create the Spnego POJO
+        // We have a negTokenTarg, and the tag must be 0xA1. We will create the SpnegoObject
         // here, and store it in the container.
         super.transitions[SpnegoStatesEnum.SPNEGO_START_STATE][0xA1] =
             new GrammarTransition( SpnegoStatesEnum.SPNEGO_START_STATE,
@@ -831,11 +831,11 @@
 
                         SpnegoContainer spnegoContainer = ( SpnegoContainer ) container;
 
-                        // First, create a empty Spnego POJO
-                        Spnego spnegoPOJO = new SpnegoNegTokenTarg();
+                        // First, create a empty SpnegoObject
+                        Spnego spnego = new SpnegoNegTokenTarg();
 
                         // Then stores it into the container
-                        spnegoContainer.setSpnego( spnegoPOJO );
+                        spnegoContainer.setSpnego( spnego );
 
                         return;
                     }
@@ -843,7 +843,7 @@
 
         // SPNEGO --> CHOICE { ...
         //      negTokenTarg  [1]  NegTokenTarg, (Length)
-        // We get the negTokenTarg length, and store it in the Spnego POJO
+        // We get the negTokenTarg length, and store it in the SpnegoObject
         super.transitions[SpnegoStatesEnum.SPNEGO_NEG_TOKEN_TARG_LENGTH][0xA1] =
             new GrammarTransition( SpnegoStatesEnum.SPNEGO_NEG_TOKEN_TARG_LENGTH,
                 SpnegoStatesEnum.SPNEGO_NEG_TOKEN_TARG_VALUE,
@@ -1075,7 +1075,7 @@
                             spnegoContainer.getSpnego();
                         TLV                    tlv             = spnegoContainer.getCurrentTLV();
 
-                        // Get the result and stores it in the POJO
+                        // Get the result and stores it in the SpnegoObject
                         byte result = tlv.getValue().getData()[0];
                         
                         if (	(result == SpnegoConstants.SPNEGO_ACCEPT_COMPLETED) || 
@@ -1202,7 +1202,7 @@
         // ...
         // MechType ::= OBJECT IDENTIFIER (Value)
         //
-        // Get the OID and store it into the Spnego POJO
+        // Get the OID and store it into the SpnegoObject
         super.transitions[SpnegoStatesEnum.SPNEGO_SUPPORTED_METH_OID_VALUE][0x06] =
             new GrammarTransition(
                 SpnegoStatesEnum.SPNEGO_SUPPORTED_METH_OID_VALUE,
@@ -1345,7 +1345,7 @@
 
         // response token OCTET STRING (Value)
         //
-        // Get the response token and store it into the Spnego POJO
+        // Get the response token and store it into the SpnegoObject
         super.transitions[SpnegoStatesEnum.SPNEGO_RESPONSE_TOKEN_OCTET_STRING_VALUE][0x04] =
             new GrammarTransition(
                 SpnegoStatesEnum.SPNEGO_RESPONSE_TOKEN_OCTET_STRING_VALUE,
@@ -1494,7 +1494,7 @@
 
         // mech list MIC OCTET STRING (Value)
         //
-        // Get the mech list MIC and store it into the Spnego POJO.
+        // Get the mech list MIC and store it into the SpnegoObject.
         // This is the last state of this grammar.
         super.transitions[SpnegoStatesEnum.SPNEGO_TARG_MECH_LIST_MIC_OCTET_STRING_VALUE][0x04] =
             new GrammarTransition(

Modified: directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/spnego/pojo/Spnego.java
URL: http://svn.apache.org/viewcvs/directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/spnego/pojo/Spnego.java?rev=189643&r1=189642&r2=189643&view=diff
==============================================================================
--- directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/spnego/pojo/SpnegoNegTokenInit.java (original)
+++ directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/spnego/pojo/SpnegoNegTokenInit.java Wed Jun  8 14:29:20 2005
@@ -18,7 +18,6 @@
 
 import java.nio.ByteBuffer;
 
-import org.apache.asn1.AbstractPOJO;
 import org.apache.asn1.ber.tlv.Length;
 import org.apache.asn1.codec.EncoderException;
 import org.apache.asn1.primitives.OID;
@@ -26,12 +25,12 @@
 
 
 /**
- * The Spnego NegTokenInit POJO contains the he Negotiation token 
+ * The Spnego NegTokenInit ldapObject contains the he Negotiation token 
  * sent from the client to the server. 
  * 
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  */
-public class SpnegoNegTokenInit extends AbstractPOJO implements Spnego
+public class SpnegoNegTokenInit extends Spnego
 {
     //~ Instance fields ----------------------------------------------------------------------------
 

Modified: directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/spnego/pojo/SpnegoNegTokenTarg.java
URL: http://svn.apache.org/viewcvs/directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/spnego/pojo/SpnegoNegTokenTarg.java?rev=189643&r1=189642&r2=189643&view=diff
==============================================================================
--- directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/spnego/pojo/SpnegoNegTokenTarg.java (original)
+++ directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/spnego/pojo/SpnegoNegTokenTarg.java Wed Jun  8 14:29:20 2005
@@ -16,17 +16,16 @@
  */
 package org.apache.asn1.spnego.pojo;
 
-import org.apache.asn1.AbstractPOJO;
 import org.apache.asn1.primitives.OID;
 import org.apache.asn1.primitives.OctetString;
 
 
 /**
- * The SpnegoNegTokenTarg POJO contains the server's response to NegTokenInit
+ * The SpnegoNegTokenTarg ldapObject contains the server's response to NegTokenInit
  * 
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  */
-public class SpnegoNegTokenTarg extends AbstractPOJO implements Spnego
+public class SpnegoNegTokenTarg extends Spnego
 {
     //~ Instance fields ----------------------------------------------------------------------------
--- directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ber/grammar/AbstractGrammar.java (original)
+++ directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ber/grammar/AbstractGrammar.java Wed Jun  8 14:29:20 2005
@@ -16,8 +16,7 @@
  */
 package org.apache.asn1.ber.grammar;
 
-import org.apache.asn1.AbstractPOJO;
-import org.apache.asn1.Asn1POJO;
+import org.apache.asn1.Asn1Object;
 import org.apache.asn1.DecoderException;
 import org.apache.asn1.ber.containers.IAsn1Container;
 import org.apache.asn1.ber.tlv.TLV;
@@ -80,15 +79,15 @@
      * Checks the Length. If the current TLV length is above the expected length of the 
      * PDU, an exception is thrown.
      * 
      * The current POJO contains the sum of all included POJOs and element, which is
      * compared with the PDU's expected length (the Length part of the PDU containing the POJO).
      * 
      * @param ldapPOJO The POJO that is being decoded.
      * @param tlv The current TLV
      * @throws DecoderException Thrown if the expected length is lower than the sum
      * of all the included elements.
      */
-    protected void checkLength( Asn1POJO ldapPOJO, TLV tlv ) throws DecoderException
+    protected void checkLength( Asn1Object ldapObject, TLV tlv ) throws DecoderException
     {
 
         // Create a new expected Length
@@ -99,15 +98,15 @@
         if ( DEBUG )
         {
             log.debug(
-                "Expected Length = " + ( ( AbstractPOJO ) ldapPOJO ).getExpectedLength() +
-                ", current length = " + ( ( AbstractPOJO ) ldapPOJO ).getCurrentLength() +
+                "Expected Length = " + ( ( Asn1Object ) ldapObject ).getExpectedLength() +
+                ", current length = " + ( ( Asn1Object ) ldapObject ).getCurrentLength() +
                 ", added length = " + expectedLength +
                 ", tlv length = " + tlvLength );
         }
 
         // We already are at the top level.
         // An exception will be thrown if the current length exceed the expected length
-        ( ( AbstractPOJO ) ldapPOJO ).addLength( expectedLength + tlvLength );
+        ( ( Asn1Object ) ldapObject ).addLength( expectedLength + tlvLength );
     }
 
     /**
@@ -80,15 +79,15 @@
      * PDU, an exception is thrown.
      * 
-     * The current POJO contains the sum of all included POJOs and element, which is
-     * compared with the PDU's expected length (the Length part of the PDU containing the POJO).
+     * The current Object contains the sum of all included Objects and element, which is
+     * compared with the PDU's expected length (the Length part of the PDU containing the Object).
      * 
@@ -80,15 +79,15 @@
      * 
-     * @param ldapPOJO The POJO that is being decoded.
+     * @param ldapObject The Object that is being decoded.
      * @param tlv The current TLV
      * @throws DecoderException Thrown if the expected length is lower than the sum

Modified: directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/LdapMessageContainer.java
URL: http://svn.apache.org/viewcvs/directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/LdapMessageContainer.java?rev=189643&r1=189642&r2=189643&view=diff
==============================================================================
--- directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/BindRequestGrammar.java (original)
+++ directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/BindRequestGrammar.java Wed Jun  8 14:29:20 2005
@@ -108,7 +108,7 @@
 
                         checkLength( ldapMessage, ldapMessageContainer.getCurrentTLV() );
 
                         // Now, we can allocate the BindRequest POJO
                         BindRequest bindRequest = new BindRequest();
 
                         // As this is a new Constructed object, we have to init its length
@@ -117,9 +117,9 @@
 
                         bindRequest.setExpectedLength( expectedLength );
                         bindRequest.setCurrentLength( 0 );
-                        bindRequest.setFather( ldapMessage );
+                        bindRequest.setParent( ldapMessage );
 
                         // And we associate it to the ldapMessage POJO
                         ldapMessage.setProtocolOP( bindRequest );
                     }
                 } );
@@ -253,7 +253,7 @@
 
         // AuthenticationChoice ::= CHOICE {
         //        simple         [0] OCTET STRING, (Length)
         // We just have to check the length, and to allocate an authentication POJO
         super.transitions[LdapStatesEnum.BIND_REQUEST_AUTHENTICATION_SIMPLE_LENGTH][( 0x80 & 0x00FF )] =
             new GrammarTransition( LdapStatesEnum.BIND_REQUEST_AUTHENTICATION_SIMPLE_LENGTH,
                 LdapStatesEnum.BIND_REQUEST_AUTHENTICATION_SIMPLE_VALUE,
@@ -271,12 +271,12 @@
 
                         checkLength( bindRequestMessage, tlv );
 
                         // Allocate the Authentication POJO
                         SimpleAuthentication authentication = null;
                         
                         authentication = new SimpleAuthentication();
 
-                        authentication.setFather( bindRequestMessage );
+                        authentication.setParent( bindRequestMessage );
 
                         bindRequestMessage.setAuthentication( authentication );
 
@@ -292,7 +292,7 @@
 
         // AuthenticationChoice ::= CHOICE {
         //        simple         [0] OCTET STRING, (Value)
         // We have to create an Authentication POJO to store the credentials.
         // The nextState is GRAMMAR_END
         super.transitions[LdapStatesEnum.BIND_REQUEST_AUTHENTICATION_SIMPLE_VALUE][( 0x80 & 0x00FF )] =
             new GrammarTransition( LdapStatesEnum.BIND_REQUEST_AUTHENTICATION_SIMPLE_VALUE,
@@ -359,12 +359,12 @@
                         
                         checkLength( bindRequestMessage, tlv );
 
                         // Create the SaslAuthentication POJO
                         SaslAuthentication authentication = null;
 
                         authentication = new SaslAuthentication();
 
-                        authentication.setFather( bindRequestMessage );
+                        authentication.setParent( bindRequestMessage );
 
                         bindRequestMessage.setAuthentication( authentication );
 
@@ -388,7 +388,7 @@
         super.transitions[LdapStatesEnum.BIND_REQUEST_AUTHENTICATION_MECHANISM_VALUE][( 0x83 & 0x00FF )] =
             new GrammarTransition( LdapStatesEnum.BIND_REQUEST_AUTHENTICATION_MECHANISM_VALUE,
                 LdapStatesEnum.BIND_REQUEST_AUTHENTICATION_CREDENTIALS_TAG,
-                new GrammarAction( "Create Bind sasl Authentication POJO" )
+                new GrammarAction( "Create Bind sasl Authentication Object" )
                 {
                     public void action( IAsn1Container container ) throws DecoderException
                     {
@@ -108,7 +108,7 @@
                         checkLength( ldapMessage, ldapMessageContainer.getCurrentTLV() );
 
-                        // Now, we can allocate the BindRequest POJO
+                        // Now, we can allocate the BindRequest Object
                         BindRequest bindRequest = new BindRequest();
 
@@ -117,9 +117,9 @@
 
-                        // And we associate it to the ldapMessage POJO
+                        // And we associate it to the ldapMessage Object
                         ldapMessage.setProtocolOP( bindRequest );
                     }
@@ -253,7 +253,7 @@
         // AuthenticationChoice ::= CHOICE {
         //        simple         [0] OCTET STRING, (Length)
-        // We just have to check the length, and to allocate an authentication POJO
+        // We just have to check the length, and to allocate an authentication Object
         super.transitions[LdapStatesEnum.BIND_REQUEST_AUTHENTICATION_SIMPLE_LENGTH][( 0x80 & 0x00FF )] =
             new GrammarTransition( LdapStatesEnum.BIND_REQUEST_AUTHENTICATION_SIMPLE_LENGTH,
@@ -271,12 +271,12 @@
                         checkLength( bindRequestMessage, tlv );
 
-                        // Allocate the Authentication POJO
+                        // Allocate the Authentication Object
                         SimpleAuthentication authentication = null;
                         
@@ -292,7 +292,7 @@
         // AuthenticationChoice ::= CHOICE {
         //        simple         [0] OCTET STRING, (Value)
-        // We have to create an Authentication POJO to store the credentials.
+        // We have to create an Authentication Object to store the credentials.
         // The nextState is GRAMMAR_END
         super.transitions[LdapStatesEnum.BIND_REQUEST_AUTHENTICATION_SIMPLE_VALUE][( 0x80 & 0x00FF )] =
@@ -359,12 +359,12 @@
                         checkLength( bindRequestMessage, tlv );
 
-                        // Create the SaslAuthentication POJO
+                        // Create the SaslAuthentication Object
                         SaslAuthentication authentication = null;
 

Modified: directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/BindResponseGrammar.java
URL: http://svn.apache.org/viewcvs/directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/BindResponseGrammar.java?rev=189643&r1=189642&r2=189643&view=diff
==============================================================================
--- directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/FilterGrammar.java (original)
+++ directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/FilterGrammar.java Wed Jun  8 14:29:20 2005
@@ -16,7 +16,7 @@
  */
 package org.apache.asn1.ldap.codec.grammars;
 
-import org.apache.asn1.AbstractPOJO;
+import org.apache.asn1.Asn1Object;
 import org.apache.asn1.DecoderException;
 import org.apache.asn1.ber.containers.IAsn1Container;
 import org.apache.asn1.ber.grammar.AbstractGrammar;
@@ -86,7 +86,7 @@
         // The Or child will also have two children.
         //
         // We know when we have a children while decoding the PDU, because the length
         // of its father has not yet reached its expected length.
         //
         // This search filter :
         // (&(|(objectclass=top)(ou=contacts))(!(objectclass=ttt))(objectclass=*top))
@@ -131,10 +131,10 @@
         //+-----------------------------* end level 2, end level 1 ------*
         //+-----------------------------+----------------+---------------+
         //
         // When the current length equals the expected length of the father PDU,
         // then we are able to 'close' the father : it has all its children. This
         // is propagated through all the tree, until either there are no more
         // parents, or the expected length of the father is different from the
         // current length.
         //                              
         //============================================================================================
@@ -247,19 +247,19 @@
                             // against the parent.
                             checkLength( currentFilter, tlv );
                             currentFilter.addFilter(andFilter);
-                            andFilter.setFather( currentFilter );
+                            andFilter.setParent( currentFilter );
                         }
                         else
                         {
                             // No parent. This Filter will become the root.
                             // First, check the length to see if it does not exceed its father
                             // expected length. (If there is no parent, we have to check the
                             // length against the SearchRequest )
                             checkLength( searchRequest, tlv );
 
                             searchRequest.setCurrentFilter(andFilter);
                             searchRequest.setFilter(andFilter);
-                            andFilter.setFather( searchRequest );
+                            andFilter.setParent( searchRequest );
                         }
 
                         // As this is a new Constructed object, we have to init its length
@@ -309,17 +309,17 @@
                             // against the parent.
                             checkLength( currentFilter, tlv );
                             currentFilter.addFilter(orFilter);
-                            orFilter.setFather( currentFilter );
+                            orFilter.setParent( currentFilter );
                         }
                         else
                         {
                             // No parent. This Filter will become the root.
                             // First, check the length to see if it does not exceed its father
                             // expected length. (If there is no parent, we have to check the
                             // length against the SearchRequest )
                             checkLength( searchRequest, tlv );
                             searchRequest.setFilter(orFilter);
-                            orFilter.setFather( searchRequest );
+                            orFilter.setParent( searchRequest );
                         }
 
                         searchRequest.setCurrentFilter(orFilter);
@@ -371,19 +371,19 @@
                             // against the parent.
                             checkLength( currentFilter, tlv );
                             currentFilter.addFilter(notFilter);
-                            notFilter.setFather( currentFilter );
+                            notFilter.setParent( currentFilter );
                         }
                         else
                         {
                             // No parent. This Filter will become the root.
                             // First, check the length to see if it does not exceed its father
                             // expected length. (If there is no parent, we have to check the
                             // length against the SearchRequest )
                             checkLength( searchRequest, tlv );
 
                             searchRequest.setCurrentFilter(notFilter);
                             searchRequest.setFilter(notFilter);
-                            notFilter.setFather( searchRequest );
+                            notFilter.setParent( searchRequest );
                         }
 
                         searchRequest.setCurrentFilter(notFilter);
@@ -435,18 +435,18 @@
                             // against the parent.
                             checkLength( currentFilter, tlv );
                             currentFilter.addFilter(equalityMatchFilter);
-                            equalityMatchFilter.setFather( currentFilter );
+                            equalityMatchFilter.setParent( currentFilter );
                         }
                         else
                         {
                             // No parent. This Filter will become the root.
                             // First, check the length to see if it does not exceed its father
                             // expected length. (If there is no parent, we have to check the
                             // length against the SearchRequest )
                             checkLength( searchRequest, tlv );
 
                             searchRequest.setCurrentFilter(equalityMatchFilter);
-                            equalityMatchFilter.setFather( searchRequest );
+                            equalityMatchFilter.setParent( searchRequest );
                             searchRequest.setFilter(equalityMatchFilter);
                         }
 
@@ -631,9 +631,9 @@
                 {
                     // The current element is not terminal, but it has been fully decoded
                     // so we will pop it from the stack
-                    AbstractPOJO element = currentFilter.getFather();
+                    Asn1Object element = currentFilter.getParent();
                     
                     // We have to check that the father is a Filter.
                     if (element instanceof Filter)
                     {
                         currentFilter = (Filter)element;
@@ -656,7 +656,7 @@
             else
             {
                 // The current element is a terminal element
-                currentFilter = (Filter)currentFilter.getFather();
+                currentFilter = (Filter)currentFilter.getParent();
             }
         }
         
@@ -86,7 +86,7 @@
         //
         // We know when we have a children while decoding the PDU, because the length
-        // of its father has not yet reached its expected length.
+        // of its parent has not yet reached its expected length.
         //
         // This search filter :
@@ -131,10 +131,10 @@
         //+-----------------------------+----------------+---------------+
         //
-        // When the current length equals the expected length of the father PDU,
-        // then we are able to 'close' the father : it has all its children. This
+        // When the current length equals the expected length of the parent PDU,
+        // then we are able to 'close' the parent : it has all its children. This
         // is propagated through all the tree, until either there are no more
@@ -131,10 +131,10 @@
         // is propagated through all the tree, until either there are no more
-        // parents, or the expected length of the father is different from the
+        // parents, or the expected length of the parent is different from the
         // current length.
         //                              
@@ -247,19 +247,19 @@
                         {
                             // No parent. This Filter will become the root.
-                            // First, check the length to see if it does not exceed its father
+                            // First, check the length to see if it does not exceed its parent
                             // expected length. (If there is no parent, we have to check the
                             // length against the SearchRequest )
@@ -309,17 +309,17 @@
                         {
                             // No parent. This Filter will become the root.
-                            // First, check the length to see if it does not exceed its father
+                            // First, check the length to see if it does not exceed its parent
                             // expected length. (If there is no parent, we have to check the
                             // length against the SearchRequest )
@@ -371,19 +371,19 @@
                         {
                             // No parent. This Filter will become the root.
-                            // First, check the length to see if it does not exceed its father
+                            // First, check the length to see if it does not exceed its parent
                             // expected length. (If there is no parent, we have to check the
                             // length against the SearchRequest )
@@ -435,18 +435,18 @@
                         {
                             // No parent. This Filter will become the root.
-                            // First, check the length to see if it does not exceed its father
+                            // First, check the length to see if it does not exceed its parent
                             // expected length. (If there is no parent, we have to check the
                             // length against the SearchRequest )
@@ -631,9 +631,9 @@
                     
-                    // We have to check that the father is a Filter.
+                    // We have to check that the parent is a Filter.
                     if (element instanceof Filter)
                     {

Modified: directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/LdapMessageGrammar.java
URL: http://svn.apache.org/viewcvs/directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/codec/grammars/LdapMessageGrammar.java?rev=189643&r1=189642&r2=189643&view=diff
==============================================================================
--- directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/BindRequest.java (original)
+++ directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/BindRequest.java Wed Jun  8 14:29:20 2005
@@ -16,18 +16,17 @@
  */
 package org.apache.asn1.ldap.pojo;
 
-import org.apache.asn1.AbstractPOJO;
-import org.apache.asn1.Asn1POJO;
+import org.apache.asn1.Asn1Object;
 import org.apache.asn1.util.MutableString;
 
 /**
  * A BindRequest POJO. It's a sub-class of AbstractPOJO, and it implements
  * the Asn1POJO interface to be seen as a member of the LdapMessage
  * CHOICE.
  * 
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  */
-public class BindRequest extends AbstractPOJO
+public class BindRequest extends Asn1Object
 {
     //~ Instance fields ----------------------------------------------------------------------------
 
@@ -38,7 +37,7 @@
     private MutableString      name;
 
     /** The authentication used to bind the user */
-    private Asn1POJO authentication;
+    private Asn1Object authentication;
 
     //~ Constructors -------------------------------------------------------------------------------
 
@@ -57,7 +56,7 @@
      *
      * @return The user authentication
      */
-    public Asn1POJO getAuthentication()
+    public Asn1Object getAuthentication()
     {
 
         return authentication;
@@ -90,7 +89,7 @@
      *
      * @param authentication The user authentication
      */
-    public void setAuthentication( Asn1POJO authentication )
+    public void setAuthentication( Asn1Object authentication )
     {
         this.authentication = authentication;
     }
@@ -16,18 +16,17 @@
 
 /**
- * A BindRequest POJO. It's a sub-class of AbstractPOJO, and it implements
- * the Asn1POJO interface to be seen as a member of the LdapMessage
+ * A BindRequest ldapObject. It's a sub-class of Asn1Object, and it extends
+ * the Asn1Object class to be seen as a member of the LdapMessage
  * CHOICE.
  * 

Modified: directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/Controls.java
URL: http://svn.apache.org/viewcvs/directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/Controls.java?rev=189643&r1=189642&r2=189643&view=diff
==============================================================================
--- directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/LdapMessage.java (original)
+++ directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/LdapMessage.java Wed Jun  8 14:29:20 2005
@@ -16,16 +16,15 @@
  */
 package org.apache.asn1.ldap.pojo;
 
-import org.apache.asn1.AbstractPOJO;
-import org.apache.asn1.Asn1POJO;
+import org.apache.asn1.Asn1Object;
 
 /**
  * The main POJO : every Ldap Message are encapsulated in it. It has a
  * messageId and Controls.
  * 
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  */
-public class LdapMessage extends AbstractPOJO
+public class LdapMessage extends Asn1Object
 {
     //~ Instance fields ----------------------------------------------------------------------------
 
@@ -33,7 +32,7 @@
     private int messageId;
 
     /** The request or response being carried by the message */
-    private Asn1POJO protocolOp;
+    private Asn1Object protocolOp;
 
     /** The controls */
     private Controls[] controls;
@@ -51,11 +50,11 @@
     //~ Methods ------------------------------------------------------------------------------------
 
     /**
      * Get the ControlPOJO at a specific index 
      *
      * @param i The index of the ControlPOJO to get
      *
      * @return The selected ControlPOJO
      */
     public Controls getControls( int i )
     {
@@ -99,16 +98,16 @@
      *
      * @return Returns the protocolOP.
      */
-    public Asn1POJO getProtocolOp()
+    public Asn1Object getProtocolOp()
     {
         return protocolOp;
     }
 
     /**
      * Get a BindResponse POJO, assuming that the caller knows that
      * it is the LdapMessage exact type.
      *
      * @return Returns the BindResponse POJO.
      */
     public BindResponse getBindResponse()
     {
@@ -116,10 +115,10 @@
     }
 
     /**
      * Get a BindRequest POJO, assuming that the caller knows that
      * it is the LdapMessage exact type.
      *
      * @return Returns the BindRequest POJO.
      */
     public BindRequest getBindRequest()
     {
@@ -127,10 +126,10 @@
     }
 
     /**
      * Get a SearchRequest POJO, assuming that the caller knows that
      * it is the LdapMessage exact type.
      *
      * @return Returns the SearchRequest POJO.
      */
     public SearchRequest getSearchRequest()
     {
@@ -142,7 +141,7 @@
      *
      * @param protocolOp The protocolOp to set.
      */
-    public void setProtocolOP( Asn1POJO protocolOp )
+    public void setProtocolOP( Asn1Object protocolOp )
     {
         this.protocolOp = protocolOp;
     }
@@ -16,16 +16,15 @@
 
 /**
- * The main POJO : every Ldap Message are encapsulated in it. It has a
+ * The main ldapObject : every Ldap Message are encapsulated in it. It has a
  * messageId and Controls.
  * 
@@ -51,11 +50,11 @@
 
     /**
-     * Get the ControlPOJO at a specific index 
+     * Get the Control Object at a specific index 
      *
@@ -51,11 +50,11 @@
      *
-     * @param i The index of the ControlPOJO to get
+     * @param i The index of the Control Object to get
      *
@@ -51,11 +50,11 @@
      *
-     * @return The selected ControlPOJO
+     * @return The selected Control Object
      */
     public Controls getControls( int i )
@@ -99,16 +98,16 @@
 
     /**
-     * Get a BindResponse POJO, assuming that the caller knows that
+     * Get a BindResponse ldapObject, assuming that the caller knows that
      * it is the LdapMessage exact type.
      *
@@ -99,16 +98,16 @@
      * it is the LdapMessage exact type.
      *
-     * @return Returns the BindResponse POJO.
+     * @return Returns the BindResponse ldapObject.
      */
     public BindResponse getBindResponse()
@@ -116,10 +115,10 @@
 
     /**
-     * Get a BindRequest POJO, assuming that the caller knows that
+     * Get a BindRequest ldapObject, assuming that the caller knows that
      * it is the LdapMessage exact type.
      *
@@ -116,10 +115,10 @@
      * it is the LdapMessage exact type.
      *
-     * @return Returns the BindRequest POJO.
+     * @return Returns the BindRequest ldapObject.
      */
     public BindRequest getBindRequest()
@@ -127,10 +126,10 @@
 
     /**
-     * Get a SearchRequest POJO, assuming that the caller knows that
+     * Get a SearchRequest ldapObject, assuming that the caller knows that
      * it is the LdapMessage exact type.
      *
@@ -127,10 +126,10 @@
      * it is the LdapMessage exact type.
      *
-     * @return Returns the SearchRequest POJO.
+     * @return Returns the SearchRequest ldapObject.
      */
     public SearchRequest getSearchRequest()

Modified: directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/LdapResult.java
URL: http://svn.apache.org/viewcvs/directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/LdapResult.java?rev=189643&r1=189642&r2=189643&view=diff
==============================================================================
--- directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/LdapResult.java (original)
+++ directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/LdapResult.java Wed Jun  8 14:29:20 2005
@@ -16,16 +16,16 @@
  */
 package org.apache.asn1.ldap.pojo;
 
-import org.apache.asn1.AbstractPOJO;
+import org.apache.asn1.Asn1Object;
 import org.apache.asn1.util.MutableString;
 
 
 /**
  * A POJO to store the LdapResult
  * 
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  */
-public class LdapResult extends AbstractPOJO
+public class LdapResult extends Asn1Object
 {
     //~ Instance fields ----------------------------------------------------------------------------
 
@@ -16,16 +16,16 @@
 
 /**
- * A POJO to store the LdapResult
+ * A ldapObject to store the LdapResult
  * 
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>

Modified: directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/Response.java
URL: http://svn.apache.org/viewcvs/directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/Response.java?rev=189643&r1=189642&r2=189643&view=diff
==============================================================================
--- directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/SaslAuthentication.java (original)
+++ directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/SaslAuthentication.java Wed Jun  8 14:29:20 2005
@@ -16,16 +16,16 @@
  */
 package org.apache.asn1.ldap.pojo;
 
-import org.apache.asn1.AbstractPOJO;
+import org.apache.asn1.Asn1Object;
 import org.apache.asn1.util.MutableString;
 
 
 /**
  * A POJO which stores the SASL authentication of a BindRequest.
  * 
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  */
-public class SaslAuthentication extends AbstractPOJO
+public class SaslAuthentication extends Asn1Object
 {
     //~ Instance fields ----------------------------------------------------------------------------
 
@@ -16,16 +16,16 @@
 
 /**
- * A POJO which stores the SASL authentication of a BindRequest.
+ * A ldapObject which stores the SASL authentication of a BindRequest.
  * 
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>

Modified: directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/SearchRequest.java
URL: http://svn.apache.org/viewcvs/directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/SearchRequest.java?rev=189643&r1=189642&r2=189643&view=diff
==============================================================================
--- directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/SearchRequest.java (original)
+++ directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/SearchRequest.java Wed Jun  8 14:29:20 2005
@@ -16,7 +16,7 @@
  */
 package org.apache.asn1.ldap.pojo;
 
-import org.apache.asn1.AbstractPOJO;
+import org.apache.asn1.Asn1Object;
 import org.apache.asn1.ldap.pojo.filters.Filter;
 import org.apache.asn1.util.MutableString;
 
@@ -24,13 +24,13 @@
 
 
 /**
  * A SearchRequest POJO. It's a sub-class of AbstractPOJO, and it implements
  * the Asn1POJO interface to be seen as a member of the LdapMessage
  * CHOICE.
  * 
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  */
-public class SearchRequest extends AbstractPOJO
+public class SearchRequest extends Asn1Object
 {
     //~ Instance fields ----------------------------------------------------------------------------
 
@@ -24,13 +24,13 @@
 
 /**
- * A SearchRequest POJO. It's a sub-class of AbstractPOJO, and it implements
- * the Asn1POJO interface to be seen as a member of the LdapMessage
+ * A SearchRequest ldapObject. It's a sub-class of Asn1Object, and it implements
+ * the ldapObject class to be seen as a member of the LdapMessage
  * CHOICE.
  * 

Modified: directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/SimpleAuthentication.java
URL: http://svn.apache.org/viewcvs/directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/SimpleAuthentication.java?rev=189643&r1=189642&r2=189643&view=diff
==============================================================================
--- directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/SimpleAuthentication.java (original)
+++ directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/SimpleAuthentication.java Wed Jun  8 14:29:20 2005
@@ -16,14 +16,14 @@
  */
 package org.apache.asn1.ldap.pojo;
 
-import org.apache.asn1.AbstractPOJO;
+import org.apache.asn1.Asn1Object;
 
 /**
  * A POJO which stores the Simple authentication of a BindRequest.
  * 
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  */
-public class SimpleAuthentication extends AbstractPOJO
+public class SimpleAuthentication extends Asn1Object
 {
     //~ Instance fields ----------------------------------------------------------------------------
 
@@ -16,14 +16,14 @@
 
 /**
- * A POJO which stores the Simple authentication of a BindRequest.
+ * A ldapObject which stores the Simple authentication of a BindRequest.
  * 
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>

Modified: directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/SubstringFilter.java
URL: http://svn.apache.org/viewcvs/directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/SubstringFilter.java?rev=189643&r1=189642&r2=189643&view=diff
==============================================================================
--- directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/UnBindRequest.java (original)
+++ directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/UnBindRequest.java Wed Jun  8 14:29:20 2005
@@ -16,18 +16,18 @@
  */
 package org.apache.asn1.ldap.pojo;
 
-import org.apache.asn1.AbstractPOJO;
+import org.apache.asn1.Asn1Object;
 
 /**
  * A UnBindRequest POJO. It's a sub-class of AbstractPOJO, and it implements
  * the Asn1POJO interface to be seen as a member of the LdapMessage
  * CHOICE. 
  * 
- * This POJO is empty.
+ * This ldapObject is empty.
  * 
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  */
-public class UnBindRequest extends AbstractPOJO
+public class UnBindRequest extends Asn1Object
 {
     //~ Instance fields ----------------------------------------------------------------------------
 
@@ -16,18 +16,18 @@
 
 /**
- * A UnBindRequest POJO. It's a sub-class of AbstractPOJO, and it implements
- * the Asn1POJO interface to be seen as a member of the LdapMessage
+ * A UnBindRequest ldapObject. It's a sub-class of Asn1Object, and it implements
+ * the ldapObject class to be seen as a member of the LdapMessage
  * CHOICE. 
  * 

Modified: directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/filters/AndFilter.java
URL: http://svn.apache.org/viewcvs/directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/filters/AndFilter.java?rev=189643&r1=189642&r2=189643&view=diff
==============================================================================
--- directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/filters/Filter.java (original)
+++ directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/filters/Filter.java Wed Jun  8 14:29:20 2005
@@ -16,18 +16,18 @@
  */
 package org.apache.asn1.ldap.pojo.filters;
 
-import org.apache.asn1.AbstractPOJO;
+import org.apache.asn1.Asn1Object;
 import org.apache.asn1.ldap.pojo.SubstringFilter;
 
 import java.util.ArrayList;
 
 
 /**
  * POJO to store the filter. A filter is seen as a tree with a root.
  * 
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  */
-public abstract class Filter extends AbstractPOJO
+public abstract class Filter extends Asn1Object
 {
     //~ Instance fields ----------------------------------------------------------------------------
 
@@ -16,18 +16,18 @@
 
 /**
- * POJO to store the filter. A filter is seen as a tree with a root.
+ * A ldapObject to store the filter. A filter is seen as a tree with a root.
  * 
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>

Modified: directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/filters/NotFilter.java
URL: http://svn.apache.org/viewcvs/directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/ldap/pojo/filters/NotFilter.java?rev=189643&r1=189642&r2=189643&view=diff
==============================================================================
--- directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/spnego/pojo/Spnego.java (original)
+++ directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/spnego/pojo/Spnego.java Wed Jun  8 14:29:20 2005
@@ -16,15 +16,15 @@
  */
 package org.apache.asn1.spnego.pojo;
 
-import org.apache.asn1.Asn1POJO;
+import org.apache.asn1.Asn1Object;
 
 /**
  * The Spnego POJO interface is used as a simple way to access to the
  * Asn1POJO members. 
  * 
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  */
-public interface Spnego extends Asn1POJO
+public class Spnego extends Asn1Object
 {
     byte NEG_TOKEN_SEQUENCE_BYTE = (byte)0x30;
 
@@ -16,15 +16,15 @@
 
 /**
- * The Spnego POJO interface is used as a simple way to access to the
- * Asn1POJO members. 
+ * The SpnegoObject interface is used as a simple way to access to the
+ * Asn1Object members. 
  * 
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>

Modified: directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/spnego/pojo/SpnegoNegTokenInit.java
URL: http://svn.apache.org/viewcvs/directory/sandbox/trunk/asn1-new-codec/src/java/org/apache/asn1/spnego/pojo/SpnegoNegTokenInit.java?rev=189643&r1=189642&r2=189643&view=diff
==============================================================================